<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>StationsPluginLyon</name>
    <message>
        <source>Network Error</source>
        <translation type="obsolete">Erreur réseau</translation>
    </message>
    <message>
        <location filename="lyon.cpp" line="169"/>
        <source>Velo&apos;V map</source>
        <translation>Carte des Velo&apos;V</translation>
    </message>
    <message>
        <location filename="lyon.cpp" line="170"/>
        <source>Show this station in the official Velo&apos;V map</source>
        <translation>Montrer cette station sur la carte officielle des Velo&apos;V</translation>
    </message>
</context>
</TS>
